@@ -1232,6 +1232,10 @@ enum response scsi_error_msg(struct burn_drive *d, unsigned char *sense,
 		else if (*ascq == 2)
 			sprintf(msg, "Timeout on logical unit");
 		return FAIL;
+	case 0x44:
+		if (*ascq == 0)
+			sprintf(msg, "Internal target failure");
+		return FAIL;
 	case 0x57:
 		if (*key != 3 || *ascq != 0)
 			break;
@@ -1558,12 +1562,12 @@ int scsi_eval_cmd_outcome(struct burn_drive *d, struct command *c, void *fp,
 	enum response outcome;
 	int done = -1, usleep_time;
 
+	if (burn_sg_log_scsi & 3)
+		scsi_log_err(c, fp, sense, sense_len, duration,
+				 (sense_len > 0) | (flag & 2));
 	if (sense_len <= 0)
 		return 1;
 		
-	if (burn_sg_log_scsi & 3)
-		scsi_log_err(c, fp, sense, sense_len, duration,
-				 1 | (flag & 2));
 	outcome = scsi_error(d, sense, sense_len);
 	if (outcome == RETRY && c->retry && !(flag & 1)) {
 		/* Calming down retries and breaking up endless cycle
