@@ -45,6 +45,17 @@ int isoburn_toc_entry_destroy(struct isoburn_toc_entry **o, int flag);
 #define Libisoburn_target_head_sizE (32*2048)
 
 
+/* Maximum number of appended partitions. Effectively usable number depends
+   on system area type.
+*/
+#define Libisoburn_max_appended_partitionS 8
+
+/*
+  Maximum length of a disc label text plus 1.
+*/
+#define Libisoburn_disc_label_sizE 129
+
+
 struct isoburn {
 
 
@@ -231,12 +242,15 @@ int isoburn_get_msc2(struct isoburn *o,
 /** Get a data source suitable for read from a drive using burn_read_data()
     function.
     @param d drive to read from. Must be grabbed.
+    @param displacement will be added or subtracted to any block address
+    @param displacement_sign  +1 = add , -1= subtract , else keep unaltered
     @return the data source, NULL on error. Must be freed with libisofs
             iso_data_source_unref() function. Note: this doesn't release
             the drive.
 */
 IsoDataSource *
-isoburn_data_source_new(struct burn_drive *d);
+isoburn_data_source_new(struct burn_drive *d,
+                         uint32_t displacement, int displacement_sign);
 
 /** Disable read capabilities of a data source which was originally created
     by isoburn_data_source_new(). After this any attempt to read will yield
@@ -321,6 +335,9 @@ struct isoburn_read_opts {
     uint32_t size; /**< Will be filled with the size (in 2048 byte block) of 
                     *   the image, as reported in the PVM. */
     unsigned int pretend_blank:1; /* always create empty image */
+
+    uint32_t displacement;
+    int displacement_sign;
 };
 
 
@@ -334,6 +351,8 @@ struct isoburn_imgen_opts {
 
     /* Options for image generation */
 
+    int will_cancel :1;
+
     int level;  /**< ISO level to write at. */
     
     /** Which extensions to support. */
@@ -556,9 +575,12 @@ struct isoburn_imgen_opts {
     /* Eventual disk file paths of prepared images which shall be appended
        after the ISO image and described by partiton table entries in a MBR.
     */
-    char *appended_partitions[4];
-    uint8_t appended_part_types[4];
+    char *appended_partitions[Libisoburn_max_appended_partitionS];
+    uint8_t appended_part_types[Libisoburn_max_appended_partitionS];
 
+    /* Eventual name of the non-ISO aspect of the image. E.g. SUN ASCII label.
+     */
+    char ascii_disc_label[Libisoburn_disc_label_sizE];
 };
 
 
