@@ -224,7 +224,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libisofs_req_major  0
 #define isoburn_libisofs_req_minor  6
-#define isoburn_libisofs_req_micro 38 
+#define isoburn_libisofs_req_micro 40 
 
 /** The minimum version of libburn to be used with this version of libisoburn
     at compile time.
@@ -287,7 +287,7 @@ int isoburn_libburn_req(int *major, int *minor, int *micro);
 */
 #define isoburn_header_version_major  0
 #define isoburn_header_version_minor  6
-#define isoburn_header_version_micro  4
+#define isoburn_header_version_micro  6
 /** Note:
     Above version numbers are also recorded in configure.ac because libtool
     wants them as parameters at build time.
@@ -819,7 +819,6 @@ int isoburn_ropt_get_default_dirperms(struct isoburn_read_opts *o,
                                       mode_t *mode);
 
 
-
 /** Set the character set for reading RR file names from ISO images.
     @since 0.1.0
     @param o             The option set to work on
@@ -834,6 +833,7 @@ int isoburn_ropt_set_input_charset(struct isoburn_read_opts *o,
 int isoburn_ropt_get_input_charset(struct isoburn_read_opts *o,
                                    char **input_charset);
 
+
 /**
     Enable or disable methods to automatically choose an input charset.
     This eventually overrides the name set via isoburn_ropt_set_input_charset()
@@ -849,6 +849,30 @@ int isoburn_ropt_set_auto_incharset(struct isoburn_read_opts *o, int mode);
 int isoburn_ropt_get_auto_incharset(struct isoburn_read_opts *o, int *mode);
 
 
+/** Control an offset to be applied to all block address pointers in the ISO
+    image in order to compensate for an eventual displacement of the image
+    relative to the start block address for which it was produced.
+    E.g. if track number 2 from CD gets copied into a disk file and shall then
+    be loaded as ISO filesystem, then the directory tree and all data file
+    content of the track copy will become readable by setting the track start
+    address as displacement and -1 as displacement_sign.
+    Data file content outside the track will of course not be accessible and
+    eventually produce read errors.
+    @since 0.6.6
+    @param o                  The option set to work on
+    @param displacement       0 or a positive number
+    @param displacement_sign  Determines wether to add or subtract displacement
+                              to block addresses before applying them to the
+                              storage object for reading:
+                              +1 = add , -1= subtract , else keep unaltered
+*/
+int isoburn_ropt_set_displacement(struct isoburn_read_opts *o,
+                               uint32_t displacement, int displacement_sign);
+int isoburn_ropt_get_displacement(struct isoburn_read_opts *o,
+                               uint32_t *displacement, int *displacement_sign);
+
+
+
 /** After calling function isoburn_read_image() there are informations
     available in the option set.
     This info can be obtained as bits in parameter has_what. Like:
@@ -873,14 +897,15 @@ int isoburn_ropt_get_auto_incharset(struct isoburn_read_opts *o, int *mode);
 #define isoburn_ropt_has_iso1999   4
 #define isoburn_ropt_has_el_torito 8
 
+int isoburn_ropt_get_size_what(struct isoburn_read_opts *o,
+                               uint32_t *size, int *has_what);
+
 /* ts A90122 */
 /* >>> to be implemented:
 #define isoburn_ropt_has_acl          64
 #define isoburn_ropt_has_ea          128
 */
 
-int isoburn_ropt_get_size_what(struct isoburn_read_opts *o,
-                               uint32_t *size, int *has_what);
 
 
 /* ----------------------------------------------------------------------- */
@@ -974,6 +999,12 @@ int isoburn_igopt_get_level(struct isoburn_imgen_opts *o, int *level);
                  the first session to LBA 32 and do not copy the first 64kB
                  of the first session to LBA 0, but rather write the first
                  session to LBA 0 directly.
+          bit10= will_cancel
+                 @since 0.6.6
+                 Announce to libisofs that only the image size is desired
+                 and that the write thread will be cancelled by
+                 isoburn_cancel_prepared_write() before actual image writing
+                 occurs. Without this, cancellation can cause a MISHAP event.
     @return 1 success, <=0 failure
 */
 #define isoburn_igopt_rockridge         1
@@ -985,6 +1016,7 @@ int isoburn_igopt_get_level(struct isoburn_imgen_opts *o, int *level);
 #define isoburn_igopt_file_md5        128
 #define isoburn_igopt_file_stability  256
 #define isoburn_igopt_no_emul_toc     512
+#define isoburn_igopt_will_cancel    1024
 int isoburn_igopt_set_extensions(struct isoburn_imgen_opts *o, int ext);
 int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
 
@@ -1239,10 +1271,22 @@ int isoburn_igopt_get_scdbackup_tag(struct isoburn_imgen_opts *o,
                              else: unspecified type 
                           @since 0.6.4
                           1= MIPS Big Endian Volume Header
-                   >>> EXPERIMENTAL:
-                   Submit MIPS boot image files as El Torito Boot image to
-                   iso_image_set_boot_image() , iso_image_add_boot_image().
-                   No El Torito info will be produced with system area type 1.
+                             Submit up to 15 MIPS Big Endian boot files by
+                             iso_image_add_mips_boot_file() of libisofs.
+                             This will overwrite the first 512 bytes of
+                             the submitted data.
+                          2= DEC Boot Block for MIPS Little Endian
+                             The first boot file submitted by
+                             iso_image_add_mips_boot_file() will be activated.
+                             This will overwrite the first 512 bytes of
+                             the submitted data.
+                          @since 0.6.6
+                          3= SUN Disk Label for SUN SPARC
+                             Submit up to 7 SPARC boot images by
+                             isoburn_igopt_set_partition_img() for partition
+                             numbers 2 to 8.
+                             This will overwrite the first 512 bytes of
+                             the submitted data.
 
     @return 1 success, 0 no data to get, <0 failure
 */
@@ -1375,23 +1419,31 @@ int isoburn_igopt_get_tail_blocks(struct isoburn_imgen_opts *opts,
 
 
 /** Cause an arbitrary data file to be appended to the ISO image and to be
-    described by a partition table entry in an MBR at the start of the
-    ISO image.
+    described by a partition table entry in an MBR or SUN Disk Label at the
+    start of the ISO image.
     The partition entry will bear the size of the image file rounded up to
     the next multiple of 2048 bytes.
+    MBR or SUN Disk Label are selected by isoburn_igopt_set_system_area()
+    system area type: 0 selects MBR partition table. 3 selects a SUN partition
+    table with 320 kB start alignment.
     @since 0.6.4
     @param opts
            The option set to be manipulated.
     @param partition_number
            Depicts the partition table entry which shall describe the
-           appended image. Range 1 to 4.
-           1 will cause the whole ISO image to be unclaimable space before
-           partition 1.
-    @param image_path
+           appended image.
+           Range with MBR: 1 to 4. 1 will cause the whole ISO image to be
+                           unclaimable space before partition 1.
+           @since 0.6.6
+           Range with SUN Disk Label: 2 to 8.
+    @param image_path 
            File address in the local file system.
+           With SUN Disk Label: an empty name causes the partition to become
+           a copy of the next lower partition.
     @param image_type
-           The partition type. E.g. FAT12 = 0x01 , FAT16 = 0x06,
+           The MBR partition type. E.g. FAT12 = 0x01 , FAT16 = 0x06,
            Linux Native Partition = 0x83. See fdisk command L.
+           This parameter is ignored with SUN Disk Label.
     @return
            <=0 = error, 1 = success
 */
@@ -1410,7 +1462,7 @@ int isoburn_igopt_set_partition_img(struct isoburn_imgen_opts *opts,
            image_paths[] of the same index is not NULL.
     @param image_paths
            Its elements get filled with either NULL or a pointer to a string
-           with a file address,
+           with a file address resp. an empty text.
     @return
            <0 = error
             0 = no partition image set
@@ -1422,6 +1474,34 @@ int isoburn_igopt_get_partition_img(struct isoburn_imgen_opts *opts,
                                     char *image_paths[]);
 
 
+/** Set a name for the system area. This setting is ignored unless system area
+    type 3 "SUN Disk Label" is in effect by iso_write_opts_set_system_area().
+    In this case it will replace the default text at the start of the image:
+      "CD-ROM Disc with Sun sparc boot created by libisofs"
+    @since 0.6.6
+    @param opts
+           The option set to be manipulated.
+    @param label
+           A text of up to 128 characters.
+    @return
+           <=0 = error, 1 = success
+*/ 
+int isoburn_igopt_set_disc_label(struct isoburn_imgen_opts *opts, char *label);
+
+/** Inquire the current setting made by isoburn_igopt_set_disc_label().
+    @since 0.6.6
+    @param opts
+           The option set to be inquired.
+    @param label
+           Returns a pointer to the currently set label string.
+           Do not alter this string.
+           Use only as long as the opts object exists.
+    @return
+           <=0 = error, 1 = success
+*/
+int isoburn_igopt_get_disc_label(struct isoburn_imgen_opts *opts,
+                                 char **label);
+
 
 /* ----------------------------------------------------------------------- */
 /*                      End of Options for image generation                */
@@ -1676,6 +1756,7 @@ int isoburn_prepare_blind_grow(struct burn_drive *in_drive,
     image stream when one of above three calls is performed. It is mandatory to
     either run isoburn_disc_write() or to revoke the preparations by the
     call described here.
+    If this call returns 0 or 1 then the write thread of libisofs has ended.
     @since 0.1.0
     @param input_drive   The drive resp. in_drive which was used with the
                          preparation call.
