@@ -309,6 +309,7 @@ int create_image(IsoImage *image, const char *image_path,
     int boot_media_type = 0;
     int load_sectors = 0; /* number of sector to load */
     unsigned char partition_type = 0;
+    off_t size;
     IsoNode *imgfile;
     IsoStream *stream;
 
@@ -317,6 +318,9 @@ int create_image(IsoImage *image, const char *image_path,
         return ret;
     }
     if (ret == 0) {
+        iso_msg_submit(image->id, ISO_NODE_DOESNT_EXIST, 0,
+                       "El Torito boot image file missing in ISO image: '%s'",
+                       image_path);
         return ISO_NODE_DOESNT_EXIST;
     }
 
@@ -331,9 +335,16 @@ int create_image(IsoImage *image, const char *image_path,
         return ISO_BOOT_IMAGE_NOT_VALID;
     }
 
+    size = iso_stream_get_size(stream);
+    if (size <= 0) {
+        iso_msg_submit(image->id, ISO_BOOT_IMAGE_NOT_VALID, 0,
+                       "Boot image file is empty");
+        return ISO_BOOT_IMAGE_NOT_VALID;
+    }
+
     switch (type) {
     case ELTORITO_FLOPPY_EMUL:
-        switch (iso_stream_get_size(stream)) {
+        switch (size) {
         case 1200 * 1024:
             boot_media_type = 1; /* 1.2 meg diskette */
             break;
@@ -471,6 +482,9 @@ int iso_image_set_boot_image(IsoImage *image, const char *image_path,
             catname[0] = '\0';
             ret = iso_tree_path_to_node(image, catdir, &p);
             if (ret <= 0) {
+                iso_msg_submit(image->id, ISO_NODE_DOESNT_EXIST, 0,
+         "Cannot find directory for El Torito boot catalog in ISO image: '%s'",
+                               catdir);
                 free(catdir);
                 return ret < 0 ? ret : ISO_NODE_DOESNT_EXIST;
             }
