@@ -184,7 +184,8 @@ int rrip_add_PL(Ecma119Image *t, Ecma119Node *n, struct susp_info *susp)
     PL[3] = 1;
 
     /* write the location of the real parent, already computed */
-    iso_bb(&PL[4], n->info.dir->real_parent->info.dir->block, 4);
+    iso_bb(&PL[4],
+       n->info.dir->real_parent->info.dir->block - t->eff_partition_offset, 4);
     return susp_append(t, susp, PL);
 }
 
@@ -277,7 +278,8 @@ int rrip_add_CL(Ecma119Image *t, Ecma119Node *n, struct susp_info *susp)
     CL[1] = 'L';
     CL[2] = 12;
     CL[3] = 1;
-    iso_bb(&CL[4], n->info.real_me->info.dir->block, 4);
+    iso_bb(&CL[4], n->info.real_me->info.dir->block - t->eff_partition_offset,
+           4);
     return susp_append(t, susp, CL);
 }
 
@@ -697,7 +699,8 @@ int susp_add_CE(Ecma119Image *t, size_t ce_len, struct susp_info *susp)
     CE[1] = 'E';
     CE[2] = 28;
     CE[3] = 1;
-    iso_bb(&CE[4], susp->ce_block, 4);
+
+    iso_bb(&CE[4], susp->ce_block - t->eff_partition_offset, 4);
     iso_bb(&CE[12], susp->ce_len, 4);
     iso_bb(&CE[20], (uint32_t) ce_len, 4);
 
