@@ -169,6 +169,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->toc_emulation_flag= 0;
  m->image_start_mode= 0;
  m->image_start_value[0]= 0;
+ m->displacement= 0;
+ m->displacement_sign= 0;
  m->drives_exclusive= 1;
  m->do_calm_drive= 1;
  m->indev[0]= 0;
@@ -225,10 +227,11 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->partition_offset= 0;
  m->partition_secs_per_head= 0;
  m->partition_heads_per_cyl= 0;
- for(i= 0; i < 4; i++) {
-   m->appended_partitions[i][0]= 0;
+ for(i= 0; i < Xorriso_max_appended_partitionS; i++) {
+   m->appended_partitions[i]= NULL;
    m->appended_part_types[i]= 0;
  }
+ m->ascii_disc_label[0]= 0;
  m->vol_creation_time= 0;
  m->vol_modification_time= 0;
  m->vol_expiration_time= 0;
@@ -241,6 +244,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
 
  m->jigdo_params= NULL;
  m->jigdo_values= NULL;
+ m->libjte_params_given= 0;
  m->loaded_boot_bin_lba= 0;
  m->loaded_boot_cat_path[0]= 0;
  m->allow_graft_points= 0;
@@ -324,6 +328,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->last_update_time= 0.0;
  m->find_compare_result= 1;
  m->find_check_md5_result= 0;
+ m->last_abort_file_time= 0.0;
 
  m->node_counter= 0;
  m->node_array_size= 0;
@@ -423,6 +428,7 @@ int Xorriso_destroy_re(struct XorrisO *m, int flag)
 int Xorriso_destroy(struct XorrisO **xorriso, int flag)
 {
  struct XorrisO *m;
+ int i;
 
  m= *xorriso;
  if(m==NULL)
@@ -450,6 +456,10 @@ int Xorriso_destroy(struct XorrisO **xorriso, int flag)
 
  Xorriso_lst_destroy_all(&(m->jigdo_params), 0);
  Xorriso_lst_destroy_all(&(m->jigdo_values), 0);
+ for(i= 0; i < Xorriso_max_appended_partitionS; i++)
+   if(m->appended_partitions[i] != NULL)
+     free(m->appended_partitions[i]);
+
  Xorriso_detach_libraries(m, flag&1);
 
  free((char *) m);
