@@ -1087,6 +1087,7 @@ int Xorriso_findx_action(struct XorrisO *xorriso, struct FindjoB *job,
  time_t date= 0;
  mode_t mode_or= 0, mode_and= ~1;
  char *target, *text_2, sfe[5*SfileadrL], *disk_prefix, iso_path[SfileadrL];
+ char *basename;
  struct FindjoB *subjob;
  struct stat stbuf; 
 
@@ -1167,6 +1168,16 @@ int Xorriso_findx_action(struct XorrisO *xorriso, struct FindjoB *job,
      Xorriso_result(xorriso,0);
    }
    {ret= 1; goto ex;}
+ } else if(action == 40) { /* estimate_size */
+   basename= strrchr(abs_path, '/');
+   if(basename != NULL)
+     basename++;
+   else
+     basename= abs_path;
+   ret= lstat(abs_path, &stbuf);
+   if(ret != -1)
+     ret= Xorriso_estimate_file_size(xorriso, job, basename, stbuf.st_mode,
+                                     stbuf.st_size, 0);
  } else {
    sprintf(xorriso->result_line, "%s\n", Text_shellsafe(show_path, sfe, 0));
    Xorriso_result(xorriso, 0);
@@ -1347,10 +1358,12 @@ ex:;
                bit5= -extract_single: eventually do not insert directory tree
 */
 int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
-                           char **src_array, char **tgt_array, int flag)
+                           char **src_array, char **tgt_array,
+                           int *problem_count, int flag)
 {
  int i, ret, with_node_array= 0, hflag= 0, hret;
 
+ *problem_count= 0;
  if(!(((xorriso->ino_behavior & 16) && xorriso->do_restore_sort_lba) ||
       (xorriso->ino_behavior & 4) || (flag & 1))) {
    ret= Xorriso_make_hln_array(xorriso, 0);
@@ -1370,8 +1383,9 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
                           (off_t) 0, (off_t) 0, hflag);
      if(ret <= 0) {
+       (*problem_count)++;
        hret= Xorriso_eval_problem_status(xorriso, ret, 0);
-       if(ret < 0)
+       if(hret < 0)
          goto ex;
      }
      with_node_array= 1;
@@ -1392,8 +1406,9 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
                           (off_t) 0, (off_t) 0, 2 << 7);
      if(ret <= 0) {
+       (*problem_count)++;
        hret= Xorriso_eval_problem_status(xorriso, ret, 0);
-       if(ret < 0)
+       if(hret < 0)
          goto ex;
      }
    }
@@ -1411,6 +1426,7 @@ int Xorriso_restore_sorted(struct XorrisO *xorriso, int count,
      ret= Xorriso_restore(xorriso, src_array[i], tgt_array[i],
                           (off_t) 0, (off_t) 0, 0);
      if(ret <= 0) {
+       (*problem_count)++;
        hret= Xorriso_eval_problem_status(xorriso, ret, flag & 32);
        if(ret < 0)
          goto ex;
