@@ -617,7 +617,7 @@ int Xorriso_genisofs_ignore(struct XorrisO *xorriso, char *whom,
  static char ignored_arg0_options[][41]= {
    "-allow-leading-dots", "-ldots", "-allow-multidot",
    "-cache-inodes", "-no-cache-inodes", "-check-oldnames", "-D",
-   "-joliet-long", "-L", "-max-iso9660-filenames", "-nobak",
+   "-L", "-max-iso9660-filenames", "-nobak",
    "-no-bak", "-force-rr", "-relaxed-filenames", "-T",
    "-no-iso-translate",
    ""
@@ -684,6 +684,7 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -output-charset CHARSET     Output charset for file name conversion",
 "  -iso-level LEVEL            Set ISO9660 conformance level (1..3)",
 "  -J, -joliet                 Generate Joliet directory information",
+"  -joliet-long                Allow Joliet file names to be 103 Unicode characters",
 "  -U, -untranslated-filenames Allow Untranslated filenames (for HPUX & AIX - violates ISO9660).",
 "  -allow-lowercase            Allow lower case characters in addition to the current character set (violates ISO9660)",
 "  -d, -omit-period            Omit trailing periods from filenames (violates ISO9660)",
@@ -754,6 +755,9 @@ int Xorriso_genisofs_help(struct XorrisO *xorriso, int flag)
 "  -partition_sec_hd NUMBER    Define number of sectors per head",
 "  -partition_hd_cyl NUMBER    Define number of heads per cylinder",
 "  -mips-boot FILE             Set mips boot image name (relative to image root)",
+"  -mipsel-boot FILE           Set mipsel boot image name (relative to image root)",
+"  -B FILES, -sparc-boot FILES Set sparc boot image names",
+"  -sparc-label label text     Set sparc boot disk label",
 "  -append_partition NUMBER TYPE FILE",
 "                              Append FILE after image. TYPE is hex: 0x..",
 "  --modification-date=YYYYMMDDhhmmsscc",
@@ -873,14 +877,14 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
  int ret, i, j, was_path= 0, was_other_option= 0, mem_graft_points, mem;
  int do_print_size= 0, fd, idx, iso_level= 0, emul_boot= 2;
  int option_b= 0, was_failure= 0, fret, lower_r= 0, zero= 0;
- int dir_mode= -1, file_mode= -1, count;
+ int dir_mode= -1, file_mode= -1, count, partition_number;
  mode_t mode_and, mode_or;
  int with_boot_image= 0, with_cat_path= 0;
  int *weight_list= NULL, weight_count= 0;
  int *delay_opt_list= NULL, delay_opt_count= 0;
  char sfe[5*SfileadrL], adr[SfileadrL+8], ra_text[80], pathspec[2*SfileadrL];
  char *ept, *add_pt, eff_path[SfileadrL], indev[SfileadrL+8], msc[80], *cpt;
- char *boot_path;
+ char *boot_path, partno_text[8];
  static char *sort_weight_args[4]= {"", "-exec", "sort_weight", ""};
 
  strcpy(ra_text, xorriso->report_about_text);
@@ -1134,6 +1138,10 @@ illegal_c:;
      lower_r= 1;
    } else if(strcmp(argv[i], "-J")==0 || strcmp(argv[i], "-joliet")==0) {
      xorriso->do_joliet= 1;
+   } else if(strcmp(argv[i], "-joliet-long")==0) {
+     ret= Xorriso_option_compliance(xorriso, "joliet_long_paths", 0);
+     if(ret<=0)
+       goto problem_handler_2;
    } else if(strcmp(argv[i], "-graft-points")==0) {
      xorriso->allow_graft_points= 1;
    } else if(strcmp(argv[i], "-path-list")==0 ||
@@ -1360,6 +1368,59 @@ not_enough_args:;
      if(ret <= 0)
        goto problem_handler_2;
 
+   } else if(strcmp(argv[i], "-B") == 0 ||
+             strcmp(argv[i], "-sparc-boot") == 0) {
+     i++;
+     if(strlen(argv[i]) >= SfileadrL)
+ continue;
+
+     /* Switch system area type to: SUN Disk Label */
+     strcpy(pathspec, "sparc_label=");
+     strcat(pathspec, xorriso->ascii_disc_label);
+     ret= Xorriso_option_boot_image(xorriso, "any", pathspec, 0);
+     if(ret <= 0)
+       goto problem_handler_2;
+
+     /* Interpret list of boot partition images or "..." */;
+     cpt= ept= argv[i];
+     partition_number= 2;
+     while(ept != NULL) {
+       ept= strchr(cpt, ',');
+       if(ept != NULL) {
+         strncpy(pathspec, cpt, ept - cpt);
+         pathspec[ept - cpt]= 0;
+         cpt= ept + 1;
+       } else
+         strcpy(pathspec, cpt);
+       if(strcmp(pathspec, "...") == 0) {
+         for(; partition_number <= 8; partition_number++) {
+           sprintf(partno_text, "%d", partition_number);
+           ret= Xorriso_option_append_partition(xorriso, partno_text, "0x0",
+                                                ".", 0);
+           if(ret <= 0)
+             goto problem_handler_2;
+         }
+       } else {
+         if(partition_number > 8) {
+           sprintf(xorriso->info_text,
+                "-as %s -sparc-boot %s : Too many boot images", whom, argv[i]);
+           Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE",0);
+           goto problem_handler_2;
+         }
+         sprintf(partno_text, "%d", partition_number);
+         ret= Xorriso_option_append_partition(xorriso, partno_text, "0x0",
+                                              pathspec, 0);
+         if(ret <= 0)
+           goto problem_handler_2;
+         partition_number++;
+       }
+     }
+
+   } else if(strcmp(argv[i], "-sparc-label") == 0) {
+     i++;
+     strncpy(xorriso->ascii_disc_label, argv[i], Xorriso_disc_label_sizE - 1);
+     xorriso->ascii_disc_label[Xorriso_disc_label_sizE - 1] = 0;
+
    } else if(argv[i][0]=='-' && argv[i][1]!=0) {
      ret= Xorriso_genisofs_count_args(xorriso, argc - i, argv + i, &count, 1);
      if(ret > 0) {
@@ -1416,8 +1477,7 @@ problem_handler_2:;
  }
  if(do_print_size) {
    ret= Xorriso_option_print_size(xorriso, 1);
-   if(ret<=0)
-     goto ex;
+   goto ex;
  }
  if(lower_r) {
    static char *lower_r_args[3]= {"/", "-exec", "mkisofs_r"};
@@ -1618,8 +1678,8 @@ ex:;
  if(was_path && !do_print_size)
    Xorriso_pacifier_callback(xorriso, "files added", xorriso->pacifier_count,
                              xorriso->pacifier_total, "", 1);
- if(do_print_size && xorriso->volset_change_pending)
-   Xorriso_option_rollback(xorriso, 0);
+ if(do_print_size && xorriso->volset_change_pending == 1)
+   xorriso->volset_change_pending= 2;
  if(weight_list != NULL)
    free(weight_list);
  if(delay_opt_list != NULL)
