@@ -154,6 +154,7 @@ struct FindjoB {
    37= mkisofs_r
    38= sort_weight number
    39= hide on|iso_rr|joliet|off
+   40= estimate_size
  */
  int action;
  int prune;
@@ -167,6 +168,8 @@ struct FindjoB {
  int type; /* see Xorriso_set_time flag, also used as weight */
  time_t date;
  char *found_path;
+ off_t estim_upper_size;
+ off_t estim_lower_size;
  struct FindjoB *subjob;
 
  /* Errors */
