@@ -199,6 +199,37 @@ int Xorriso_option_disk_pattern(struct XorrisO *xorriso, char *mode, int flag)
 }
 
 
+/* Option -displacement [-]offset */
+int Xorriso_option_displacement(struct XorrisO *xorriso, char *value, int flag)
+{
+ double num;
+ int displacement_sign= 1, l;
+ char *cpt;
+
+ cpt= value;
+ if(value[0] == '-') {
+   displacement_sign= -1;
+   cpt++;
+ } else if(value[0] == '+')
+   cpt++;
+ num= Scanf_io_size(cpt, 0);
+ l= strlen(cpt);
+ if(cpt[l - 1] < '0' || cpt[l - 1] > '9')
+   num/= 2048.0;
+ if(num < 0.0 || num > 4294967295.0) {
+   sprintf(xorriso->info_text,
+           "-displacement: too large or too small: '%s'", value);
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+   return(0);
+ }
+ if(num == 0)
+   displacement_sign= 0;
+ xorriso->displacement= num;
+ xorriso->displacement_sign= displacement_sign;
+ return(1);
+}
+
+
 /* Option -drive_class */
 int Xorriso_option_drive_class(struct XorrisO *xorriso,
                                char *d_class, char *pattern, int flag)
@@ -310,7 +341,7 @@ int Xorriso_option_end(struct XorrisO *xorriso, int flag)
  else
    cmd= "-end";
  if(xorriso->volset_change_pending) {
-   if(flag&1)
+   if((flag & 1) || xorriso->volset_change_pending != 1)
      which_will= "end the program discarding image changes";
    else
      which_will= "commit image changes and then end the program";
@@ -324,7 +355,7 @@ int Xorriso_option_end(struct XorrisO *xorriso, int flag)
  }
 
  if(xorriso->volset_change_pending) {
-   if(flag&1) {
+   if((flag & 1) || xorriso->volset_change_pending != 1) {
      xorriso->volset_change_pending= 0;
    } else {
      ret= Xorriso_option_commit(xorriso, 1);
@@ -455,7 +486,7 @@ int Xorriso_option_external_filter(struct XorrisO *xorriso,
 int Xorriso_option_extract(struct XorrisO *xorriso, char *iso_path,
                            char *disk_path, int flag)
 {
- int ret;
+ int ret, problem_count;
  char eff_origin[SfileadrL], eff_dest[SfileadrL], *ipth, *eopt[1], *edpt[1];
 
  if(xorriso->allow_restore <= 0) {
@@ -485,12 +516,13 @@ int Xorriso_option_extract(struct XorrisO *xorriso, char *iso_path,
 
  eopt[0]= eff_origin;
  edpt[0]= eff_dest;
- ret= Xorriso_restore_sorted(xorriso, 1, eopt, edpt, (flag & 32 ? 33 : 0));
+ ret= Xorriso_restore_sorted(xorriso, 1, eopt, edpt, &problem_count,
+                             (flag & 32 ? 33 : 0));
 
  if(!(flag&2))
    Xorriso_pacifier_callback(xorriso, "files restored",xorriso->pacifier_count,
                              xorriso->pacifier_total, "", 1|4);
- if(ret<=0)
+ if(ret <= 0 || problem_count > 0)
    goto ex;
 
  if(!(flag&1)) {
@@ -975,6 +1007,8 @@ not_enough_exec_arguments:;
          goto sorry_ex;
        }
        Findjob_set_action_type(job, 39, type, 0);
+     } else if(strcmp(cpt, "estimate_size")==0) {
+       Findjob_set_action_target(job, 40, NULL, 0);
      } else {
        sprintf(xorriso->info_text, "-find -exec: unknown action %s",
                Text_shellsafe(argv[i], sfe, 0));
@@ -1009,6 +1043,15 @@ ex:;
                              xorriso->pacifier_count, 0, "", 1);
  if(first_job->action == 35 && !(flag & 1))
    Xorriso_report_md5_outcome(xorriso, first_job->target, 0);
+ if(first_job->action == 40) {
+   sprintf(xorriso->result_line,"Size lower   : %lus\n",
+          (unsigned long) (first_job->estim_lower_size / (off_t) 2048));
+   Xorriso_result(xorriso,0);
+   sprintf(xorriso->result_line,"Size upper   : %lus\n",
+          (unsigned long) ((first_job->estim_upper_size / (off_t) 2048) +
+                           !!(first_job->estim_upper_size % 2048)));
+   Xorriso_result(xorriso,0);
+ }
  if(access_acl_text != NULL)
    free(access_acl_text);
  if(default_acl_text != NULL)
@@ -1315,6 +1358,10 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "  -load \"session\"|\"track\"|\"lba\"|\"sbsector\"|\"volid\"|\"auto\" id",
 "                 Load a particular (outdated) ISO image from a -dev or",
 "                 -indev which hosts more than one session.",
+"  -displacement [-]block_address",
+"                 When loading ISO tree or reading data files compensate a",
+"                 displacement versus the start address for which the image",
+"                 was prepared.",
 "  -rom_toc_scan \"on\"|\"force\"|\"off\"[:\"emul_on\"|\"emul_off\"]",
 "                 Enable scanning for ISO sessions on read-only drives/media",
 "                 resp. on overwriteable media with emulated TOC.",
@@ -1391,6 +1438,7 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "              |\"cat_path=\"|\"cat_hidden=on|iso_rr|joliet|off\"",
 "              |\"load_size=\"|\"system_area=\"|\"partition_table=on|off\"",
 "              |\"mips_path=\"|\"mipsel_path=\"|\"mips_discard\"",
+"              |\"sparc_label=\"|\"sparc_discard\"",
 "              |\"show_status\"",
 "                 Whether to discard or keep an exiting El Torito boot image.",
 "                 ISOLINUX can be made bootable by dir=/ or dir=/isolinux",
@@ -1401,8 +1449,9 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "                 system_area= and partition_table= are for MBR based booting",
 "                 from USB stick. The system_area= file needs not to be added.",
 "                 mips_path= adds Big Endian MIPS boot files. mipsel_path=",
-"                 sets one Little Endian MIPS boot file. Both are mutually",
-"                 exclusive and exclusive to MBR production.",
+"                 sets one Little Endian MIPS boot file. sparc_label=",
+"                 activates SUN Disk Label. All three are mutually exclusive",
+"                 and exclusive to MBR production.",
 "  -append_partition partition_number type_code disk_path",
 "                 Append a prepared filesystem image after the end of the",
 "                 ISO image. Caution: Will be overwritten by multi-session.",
@@ -1759,9 +1808,10 @@ int Xorriso_option_help(struct XorrisO *xorriso, int flag)
 "Compatibility emulation (argument list may be ended by list delimiter --):",
 "  -as mkisofs  [-help|-version|-o|-R|-r|-J|-V|-P|-f|-m|-exclude-list|",
 "                -no-pad|-M|-C|-graft-points|-path-list|pathspecs|-z|",
-"                -no-emul-boot|-b|-c|-boot-info-table|-boot-load-size|-G]",
+"                -no-emul-boot|-b|-c|-boot-info-table|-boot-load-size|-G|...]",
 "              Perform some mkisofs gestures, understand pathspecs as mkisofs",
 "              does. Commit happens outside emulation at usual occasions.",
+"              For a list of options see -as mkisofs -help.",
 "  -read_mkisofsrc",
 "              Read and interpret the .mkisofsrc configuration file.",
 "  -as cdrecord [-help|-v|dev=|speed=|blank=|fs=|-eject|-atip|padsize=|-multi]",
