@@ -459,7 +459,8 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "backslash_codes","blank","biblio_file",
     "calm_drive","cd","cdi","cdx","charset","close",
     "commit_eject","compliance","copyright_file",
-    "dev","dialog","disk_dev_ino","disk_pattern","dummy","dvd_obs","eject",
+    "dev","dialog","disk_dev_ino","disk_pattern","displacement",
+    "dummy","dvd_obs","eject",
     "iso_rr_pattern","follow","format","fs","gid","grow_blindly","hardlinks",
     "history","indev","in_charset","joliet",
     "list_delimiter","list_profiles","local_charset",
@@ -817,6 +818,10 @@ next_command:;
    (*idx)++;
    ret= Xorriso_option_disk_dev_ino(xorriso, arg1, 0);
 
+ } else if(strcmp(cmd,"displacement")==0) {
+   (*idx)++;
+   ret= Xorriso_option_displacement(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"disk_pattern")==0) {
    (*idx)++;
    ret= Xorriso_option_disk_pattern(xorriso, arg1, 0);
@@ -1390,8 +1395,6 @@ eval_any_problems:
    goto next_command;
 
 ex:;
- if((!xorriso->is_dialog) && !(flag&1))
-   Xorriso_mark(xorriso,0);
  fflush(stdout);
  return(ret);
 }
