@@ -1975,6 +1975,14 @@ int Xorriso_check_md5(struct XorrisO *xorriso, void *in_node, char *path,
    xorriso->pacifier_byte_count+= rret;
    Xorriso_pacifier_callback(xorriso, "content bytes read",
                              xorriso->pacifier_count, 0, "", 0);
+   ret= Xorriso_check_for_abort(
+             xorriso,
+             xorriso->check_media_default != NULL 
+                ? xorriso->check_media_default->abort_file_path
+                : "/var/opt/xorriso/do_abort_check_media",
+             Sfile_microtime(0), &xorriso->last_abort_file_time, 0);
+   if(ret == 1)
+     {ret= -2; goto ex;}
  }
  ret= iso_md5_end(&ctx, data_md5);
  if(ret < 0)
@@ -2004,11 +2012,16 @@ ex:;
  if(ctx != NULL)
    iso_md5_end(&ctx, data_md5);
  if(ret < 0) {
-   sprintf(xorriso->result_line, "NOT READABLE: ");
+   if(ret == -2)
+     sprintf(xorriso->result_line, "Aborted at: ");
+   else
+     sprintf(xorriso->result_line, "NOT READABLE: ");
    Text_shellsafe(path, xorriso->result_line, 1);
    strcat(xorriso->result_line, "\n");
    if(!(flag & 1))
      Xorriso_result(xorriso,0);
+   if(ret == -2)
+     xorriso->request_to_abort= 1;
  }
  return(ret);
 }
