@@ -532,7 +532,7 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
 {
  int ret, relax= 0, i, pacifier_speed= 0, data_lba, ext, is_bootable= 0;
  int freshly_bootable= 0, hide_attr;
- char xorriso_id[256], *img_id, sfe[5*SfileadrL], *out_cs;
+ char xorriso_id[256], *img_id, sfe[5*SfileadrL], *out_cs, *part_image;
  struct isoburn_imgen_opts *sopts= NULL;
  struct burn_drive_info *dinfo, *source_dinfo;
  struct burn_drive *drive, *source_drive;
@@ -567,7 +567,15 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
  if(ret<=0)
    return(0);
 
+ s= isoburn_disc_get_status(drive);
  if(xorriso->out_drive_handle == xorriso->in_drive_handle) {
+   if(abs(xorriso->displacement_sign) == 1 && xorriso->displacement != 0 &&
+      s != BURN_DISC_BLANK) {
+     sprintf(xorriso->info_text,
+             "May not grow ISO image while -displacement is non-zero");
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+     {ret= 0; goto ex;}
+   }
    source_drive= drive;
  } else {
    if(xorriso->in_drive_handle == NULL) {
@@ -578,7 +586,6 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
      if(ret<=0)
        goto ex;
    }
-   s= isoburn_disc_get_status(drive);
    if(s!=BURN_DISC_BLANK) {
      s= burn_disc_get_status(drive);
      if(s!=BURN_DISC_BLANK)
@@ -722,7 +729,8 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
        ) * isoburn_igopt_aaip) |
       ((!!(xorriso->do_md5 & 2)) * isoburn_igopt_session_md5) |
       ((!!(xorriso->do_md5 & 4)) * isoburn_igopt_file_md5) |
-      ((!!(xorriso->do_md5 & 8)) * isoburn_igopt_file_stability);
+      ((!!(xorriso->do_md5 & 8)) * isoburn_igopt_file_stability) |
+      ((flag & 1) * isoburn_igopt_will_cancel);
  if(xorriso->no_emul_toc & 1)
    ext|= isoburn_igopt_no_emul_toc;
  isoburn_igopt_set_extensions(sopts, ext);
@@ -736,12 +744,20 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
  isoburn_igopt_set_scdbackup_tag(sopts, xorriso->scdbackup_tag_name,
                                  xorriso->scdbackup_tag_time,
                                  xorriso->scdbackup_tag_written);
- for(i= 0; i < 4; i++) {
+ for(i= 0; i < Xorriso_max_appended_partitionS; i++) {
+   if(xorriso->appended_partitions[i] == NULL)
+ continue;
    if(xorriso->appended_partitions[i][0] == 0)
  continue;
-   ret= isoburn_igopt_set_partition_img(sopts, i + 1,
-             xorriso->appended_part_types[i], xorriso->appended_partitions[i]);
+   if(strcmp(xorriso->appended_partitions[i], ".") == 0)
+     part_image= "";
+   else
+     part_image= xorriso->appended_partitions[i];
+   isoburn_igopt_set_partition_img(sopts, i + 1,
+                                  xorriso->appended_part_types[i], part_image);
  }
+ isoburn_igopt_set_disc_label(sopts, xorriso->ascii_disc_label); 
+
  if(image!=NULL && 12+strlen(Xorriso_timestamP)<80) {
    strcpy(xorriso_id, xorriso->preparer_id);
    img_id= (char *) iso_image_get_data_preparer_id(image);
@@ -761,14 +777,14 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
                     xorriso->vol_uuid);
 
 #ifdef Xorriso_with_libjtE
- if(xorriso->libjte_handle) {
+ if(xorriso->libjte_handle && (xorriso->libjte_params_given & (4 | 8))) {
+
+   /* >>> Check whether the mandatory parameters are set */;
+
    ret= libjte_set_outfile(xorriso->libjte_handle, xorriso->outdev);
    Xorriso_process_msg_queues(xorriso, 0);
    if(ret <= 0)
      goto ex;
-
-   /* >>> Check whether the mandatory parameters are set */;
-
    isoburn_igopt_attach_jte(sopts, xorriso->libjte_handle);
 
    /* Padding to be done by libisofs, not by libburn */
@@ -844,7 +860,7 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
 
  ret= Xorriso_make_write_options(xorriso, drive, &burn_options, 0);
  if(ret<=0)
-   goto ex;
+   goto cancel_iso;
  isoburn_igopt_get_effective_lba(sopts, &(xorriso->session_lba));
  if(xorriso->do_stream_recording == 2) {
    ret= isoburn_igopt_get_data_start(sopts, &data_lba);
@@ -857,15 +873,14 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
    Xorriso_process_msg_queues(xorriso,0);
    if(flag&1) /* set queue severity to FAILURE */
      Xorriso_set_image_severities(xorriso, 2);
-   isoburn_cancel_prepared_write(source_drive, drive, 0);
    if(flag&1) /* reset queue severity */
      Xorriso_set_image_severities(xorriso, 0);
-   goto ex;
+   goto cancel_iso;
  }
 
  ret= Xorriso_may_burn(xorriso, 0);
  if(ret <= 0)
-   goto ex;
+   goto cancel_iso;
 
  /* Important: do not return until burn_is_aborting() was checked */
  Xorriso_set_signal_handling(xorriso, 1);
@@ -939,6 +954,10 @@ ex:;
  Xorriso_process_msg_queues(xorriso,0);
  Xorriso_append_scdbackup_record(xorriso, 0);
  return(ret);
+
+cancel_iso:;
+ isoburn_cancel_prepared_write(source_drive, drive, 0);
+ goto ex;
 } 
 
 
@@ -987,8 +1006,7 @@ int Xorriso_pacifier_loop(struct XorrisO *xorriso, struct burn_drive *drive,
                           int flag)
 {
  int ret, size, free_bytes, i, aborting= 0, emul, buffer_fill= 50, last_sector;
- int iso_wait_counter= 0, iso_cancel_limit= 5, iso_break_limit= 20;
- int iso_cancelled= 0;
+ int iso_wait_counter= 0, iso_cancel_limit= 5;
  struct burn_progress progress;
  char *status_text, date_text[80], *speed_unit, mem_text[8];
  enum burn_drive_status drive_status;
@@ -1026,28 +1044,18 @@ int Xorriso_pacifier_loop(struct XorrisO *xorriso, struct burn_drive *drive,
    drive_status= burn_drive_get_status(drive, &progress);
 
    if(drive_status == BURN_DRIVE_IDLE) {
-
      /* To avoid a race condition between burn_source and libisofs
         writer thread: Wait for ISO generator thread to have finished.
+        After some seconds kick it by isoburn_cancel_prepared_write()
+        which waits for the write thread to end.
      */
      if(image == NULL)
  break;
      if(!iso_image_generator_is_running(image))
  break;
      iso_wait_counter++;
-     if(iso_wait_counter > iso_cancel_limit && !iso_cancelled) {
+     if(iso_wait_counter > iso_cancel_limit) {
        isoburn_cancel_prepared_write(drive, NULL, 0);
-       iso_cancelled= 1;
-     } else if(iso_wait_counter > iso_break_limit) {
-
-       /* >>> This can be dangerous. xorriso will free memory objects which
-              might be in use in the unstoppable libisofs thread.
-              The current implementation of ecma119.c:bs_cancel() seems to
-              wait for the writer thread to end. Probably one should make
-              this a part of the libisofs API specs and break the loop
-              directly after isoburn_cancel_prepared_write().
-       */
-
  break;
      }
    }
