@@ -64,6 +64,18 @@ struct FindjoB;           /* Program and status of a find run */
         (((off_t) 400) * ((off_t) 1024*1024*1024) - (off_t) 204800)
 
 
+/* Maximum number of appended partitions. Effectively usable number depends
+   on system area type.
+*/
+#define Xorriso_max_appended_partitionS 8
+
+
+/*
+  Maximum length of a disc label text plus 1.
+*/
+#define Xorriso_disc_label_sizE 129
+
+
 struct XorrisO { /* the global context of xorriso */
 
  int libs_are_started;
@@ -219,6 +231,9 @@ struct XorrisO { /* the global context of xorriso */
                         */
  char image_start_value[81]; /* value according image_start_mode */
 
+ uint32_t displacement;
+ int displacement_sign;
+
  int drives_exclusive;   /* burn_preset_device_open() param exclusive */
 
  int do_calm_drive;      /* bit0= calm down drive after aquiring it */
@@ -235,7 +250,11 @@ struct XorrisO { /* the global context of xorriso */
  time_t isofs_st_in;     /* That time point as read from "isofs.st" of the
                             loaded image. */
 
- int volset_change_pending; /* whether -commit would make sense */
+ int volset_change_pending; /* whether -commit would make sense
+                               0= no change pending , 1= change pending
+                               2= change pending, but -as misofs -print-size
+                                  was performed on the changed image model
+                             */
  int no_volset_present;     /* set to 1 on first failure */
 
  struct CheckmediajoB *check_media_default;
@@ -323,8 +342,12 @@ struct XorrisO { /* the global context of xorriso */
  int partition_heads_per_cyl;
 
  /* Path and type of image files to be appended as MBR partitions */
- char appended_partitions[4][SfileadrL];
- uint8_t appended_part_types[4];
+ char *appended_partitions[Xorriso_max_appended_partitionS];
+ uint8_t appended_part_types[Xorriso_max_appended_partitionS];
+
+ /* Eventual name of the non-ISO aspect of the image. E.g. SUN ASCII label.
+ */
+ char ascii_disc_label[Xorriso_disc_label_sizE];
 
  /* User settable PVD time stamps */
  time_t vol_creation_time;
@@ -343,7 +366,12 @@ struct XorrisO { /* the global context of xorriso */
  /* List of -jigdo parameters since the most recent -jigdo clear */
  struct Xorriso_lsT *jigdo_params;
  struct Xorriso_lsT *jigdo_values;
-
+ int libjte_params_given; /* bits: 0= outfile , 1= verbosity , 2= template_path
+                                   3= jigdo_path , 4= md5_path , 5= min_size
+                                   6= checksum_iso , 7= checksum_template
+                                   8= compression , 9= exclude , 10= demand_md5
+                                  11= mapping
+                          */
 
  /* LBA of boot image after image loading */
  int loaded_boot_bin_lba;
@@ -508,6 +536,8 @@ struct XorrisO { /* the global context of xorriso */
                                bit3= seen match
                              */
 
+ double last_abort_file_time; /* most recent check for aborting -check_md5 */
+
  /* Tree node collection and LBA sorting facility */
  int node_counter;
  int node_array_size;
