@@ -19,7 +19,7 @@
 */
 #define xorriso_libisoburn_req_major  0
 #define xorriso_libisoburn_req_minor  6
-#define xorriso_libisoburn_req_micro  4
+#define xorriso_libisoburn_req_micro  6
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -552,5 +552,9 @@ int Xorriso_preparer_string(struct XorrisO *xorriso, char xorriso_id[129],
 int Xorriso_jigdo_interpreter(struct XorrisO *xorriso, char *aspect, char *arg,
                               int flag);
 
+
+int Xorriso_estimate_file_size(struct XorrisO *xorriso, struct FindjoB *job,
+                      char *basename, mode_t st_mode, off_t st_size, int flag);
+
 #endif /* Xorrisoburn_includeD */
 
